from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from tensorflow.keras.models import load_model
from tensorflow.nn import softmax
from numpy import argmax
from numpy import max
from numpy import array
from json import dumps
from uvicorn import run
import os
import ast
import numpy as np

app = FastAPI()

origins = ["*"]
methods = ["*"]
headers = ["*"]

app.add_middleware(
    CORSMiddleware, 
    allow_origins = origins,
    allow_credentials = True,
    allow_methods = methods,
    allow_headers = headers    
)

model_dir = "RNNmodel.h5"
model = load_model(model_dir)

class_predictions = array([
    'run',
    'walk',
    'squats'
])

@app.get("/")
async def root():
    return {"message": "Welcome to movement classification api API!"}

@app.post("/net/move/prediction/")
async def get_net_move_prediction(table: str = ""):
    if table == "":
        return {"message": "No table provided"}
    
    parsed_table = ast.literal_eval(table)

    data = np.array(parsed_table)
    print(data.shape)
    pred = model.predict(data)
    score = softmax(pred[0])

    class_prediction = class_predictions[argmax(score)]
    model_score = round(max(score) * 100, 2)

    return {
        "model-prediction": class_prediction,
        "model-prediction-confidence-score": model_score
    }


port = int(os.environ.get('PORT', 5001))
run(app, host="0.0.0.0", port=port)